API docs for “spamfighter.core”

# Package s.core

Part of spamfighter View Source

Ядро сервера: базовые классы команд, доменов, партнеров и т.п.

Package | commands | Базовые классы для обработки команд API сервера.
Module | counters | Счетчики, анализирующие нагрузку на сервер.
Module | domain | Реализация основных классов доменов.
Module | firewall | "Черный ящик" анализа сообщений по правилам, построенный
Module | log | Лог сообщений, прошедших через firewall.
Package | message | Сообщения, атрибуты, их домены и т.п.
Package | model | Модели анализа сообщений.
Module | null_partner | Модуль авторизации партнеров без логинов/паролей (на доверии).
Module | partner | Базовые классы и методы работы с партнерами.
Module | rules | Обслуживание правил для анализа сообщений.
Package | storage | Модули подсистемы хранения данных, как персистентного, так и временного.
Package | test | Тесты на `spamfighter.core`.